
BEGIN {
  unless ($ENV{AUTHOR_TESTING}) {
    require Test::More;
    Test::More::plan(skip_all => 'these tests are for testing by the author');
  }
}

use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.006008
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib  ) );
__DATA__
CopyFiles
CopyFooBarFilesToProduction
DBI
DSL
DSN
GitHub
Stepfile
VERSIONING
YYY
YYYZZZ
iteratively
manully
namespace
namespaces
prepends
serializable
subtypes
timestamp
timestamps
username
versioning
Dave
Rolsky
drolsky
MaxMind
Inc
autarch
Gregory
Oschwald
goschwald
Olaf
Alders
olaf
Ran
Eilam
ran
lib
Stepford
Trait
StepDependency
StepProduction
Planner
LoggerWithMoniker
FinalStep
Error
Types
Internal
Role
Step
FileGenerator
Plan
